@@ -1,16 +1,13 @@
-use crate::raw::{Storage, StorageWithCapacity};
+use crate::{raw::{Storage, StorageWithCapacity}, uninit_array};
+use std::mem::MaybeUninit;
 
-unsafe impl<T: Copy, const N: usize> crate::raw::StorageInit<T> for [T; N] {}
-unsafe impl<T: Default + Copy, const N: usize> StorageWithCapacity<T> for [T; N]
-where
-    Self: Default,
-{
+unsafe impl<T, const N: usize> StorageWithCapacity<T> for [MaybeUninit<T>; N] {
     fn with_capacity(capacity: usize) -> Self {
         if capacity > N {
             crate::raw::capacity::fixed_capacity_reserve_error(N, capacity)
         }
 
-        Self::default()
+        uninit_array()
     }
 
     #[inline]
@@ -18,13 +15,13 @@ where
     #[allow(non_snake_case)]
     fn __with_capacity__const_capacity_checked(capacity: usize, old_capacity: Option<usize>) -> Self {
         match old_capacity {
-            Some(old_capacity) if old_capacity <= N => Self::default(),
+            Some(old_capacity) if old_capacity <= N => uninit_array(),
             _ => Self::with_capacity(capacity),
         }
     }
 }
 
-unsafe impl<T: Copy, const N: usize> Storage<T> for [T; N] {
+unsafe impl<T, const N: usize> Storage<T> for [MaybeUninit<T>; N] {
     #[doc(hidden)]
     const CONST_CAPACITY: Option<usize> = Some(N);
     const IS_ALIGNED: bool = true;
